@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-example-check - Reads the "O" array and the corresponding methods
+example-check.pl - Reads the "O" array and the corresponding methods
 
 =cut
 
@@ -40,3 +40,16 @@ while (1) {
   }
   sleep 1;
 }
+
+__END__
+
+=head1 SAMPLE OUTPUT
+
+  --MID28|1168722239.380|0.005|53.527136|-113.530150|704.57|1.60|1.28|0.0000|0.000|0.000||0.00||3
+  O=MID28|1168722239.380|0.005|53.527136|-113.530150|704.57|1.60|1.28|0.0000|0.000|0.000||0.00||3
+  --MID28|1168726527.070|0.005|53.527163|-113.530174|702.39|1.60|1.44|109.6857|0.053|0.169|50.9684|0.00||3
+  O=MID28|1168726527.070|0.005|53.527163|-113.530174|702.39|1.60|1.44|109.6857|0.053|0.169|50.9684|0.00||3
+  --MID29|1168726527.070|0.005|53.527163|-113.530174|702.39|1.60|1.44|109.6857|0.053|0.169|50.9684|0.00||3
+  O=MID29|1168726527.070|0.005|53.527163|-113.530174|702.39|1.60|1.44|109.6857|0.053|0.169|50.9684|0.00||3
+
+=cut
